<?
session_start();

// to reduce data size delete this from all epoch times before storing
define('EPOCHSTART', 1630000000);

//
// TOP is already defined for web/index.php and web/admin/admin.php
//

if (!defined('TOP')) {
	if (isset($_ENV['PWD'])) {
		define('TOP', dirname($_ENV['PWD']) . '/');
	}
	else {
		#define('TOP', dirname(dirname(__FILE__)) . '/');
		define('TOP', dirname(trim(shell_exec('pwd'))) . '/');
	}
}

define('TOPURL', '');
define('BIN', TOP . 'bin/');
define('URL', str_replace('//', '/', dirname($_SERVER['SCRIPT_NAME']) . '/'));
define('LIB', TOP . 'lib/');

//
// read in site config and define mysql connection info
//

if (file_exists(TOP . 'config.ini')) {
	$_AVOS['config'] = parse_ini_file(TOP . 'config.ini', true);
}
elseif (file_exists(BIN . 'config.ini')) {
	$_AVOS['config'] = parse_ini_file(BIN . 'config.ini', true);
}
else {
	echo "unable to find config";
	exit;
}

//
// exit if config.ini parse error
//

if ($_AVOS['config'] === false) {
	echo "error parsing config.ini";
	exit;
}

//
// check devMode
//

if (isset($_AVOS['config']['site']['devMode'])) {
    if ($_AVOS['config']['site']['devMode']) {
        $_AVOS['config']['site']['warnings'] = 1;
        $_AVOS['config']['site']['refresh'] = 1;
        $_AVOS['config']['site']['allowDebugFlag'] = 1;
    }
    else {
        $_AVOS['config']['site']['warnings'] = 0;
        $_AVOS['config']['site']['refresh'] = 0;
        $_AVOS['config']['site']['allowDebugFlag'] = 0;
    }
}

//
// debug
//

if (!empty($_AVOS['config']['site']['debug'])) {
	define('DEBUG', TRUE);
}
else {
	define('DEBUG', FALSE);
}

//
// perf
//

if (!empty($_AVOS['config']['site']['perf']) || isset($_GET['debug'])) {
	define('PERF', TRUE);
}
else {
	define('PERF', FALSE);
}

//
// warnings
//

if (!empty($_AVOS['config']['site']['warnings']) && $_AVOS['config']['site']['warnings'] == 1) {
	ini_set('display_errors', 1);
	ini_set('display_startup_errors', 1);
	error_reporting(E_ALL);
}
else {
	ini_set('display_errors', 'Off');
	error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
}

//
// timezone
//

if (!empty($_AVOS['config']['timezone']) && $_AVOS['config']['timezone'] == 1) {
	date_default_timezone_set($_AVOS['config']['site']['timezone']);
}
else {
	date_default_timezone_set('Europe/Bucharest');
}

define('WEB', $_AVOS['config']['site']['webDir'] . '/');

define('DB_HOST', $_AVOS['config']['mysql']['hostname']);
define('DB_USER', $_AVOS['config']['mysql']['username']);
define('DB_PASS', $_AVOS['config']['mysql']['password']);
define('DB_NAME', $_AVOS['config']['mysql']['database']);

if (isset($_AVOS['config']['mysql']['webcamsDatabase'])) {
	define('DB_CAMS', $_AVOS['config']['mysql']['webcamsDatabase']);
}
else {
	define('DB_CAMS', $_AVOS['config']['mysql']['database']);
}

//
// connect to redis
//

$redis = new Redis();
$port = isset($_AVOS['config']['redis']['port']) ? $_AVOS['config']['redis']['port'] : 6379;
$redis->connect($_AVOS['config']['redis']['hostname'], $port);
$redis->setOption(Redis::OPT_SERIALIZER, Redis::SERIALIZER_PHP);
$redis->setOption(Redis::OPT_PREFIX, "");
$_AVOS['redis'] = $redis;

/*
$redis = new Redis([
    'host' => $_AVOS['config']['redis']['hostname'],
    'port' => $_AVOS['config']['redis']['port'],
    'connectTimeout' => 2.5,
    'auth' => ['phpredis', 'phpredis'],
]);
*/

//
// lib includes
//

include(LIB . "Avos/Utils.php");
include(LIB . "Avos/Scaffold.php");
include(LIB . "Avos/Routes.php");
include(LIB . "Avos/Redis.php");
include(LIB . "Avos/Database.php");
include(LIB . "Avos/SQLite.php");
include(LIB . "Avos/Cron.php");
include(LIB . "Avos/Videos.php");
include(LIB . "Avos/Photos.php");
include(LIB . "Avos/Blogs.php");
include(LIB . "Avos/Webcams.php");
include(LIB . "Avos/Rpc.php");
include(LIB . "Avos/Render.php");
include(LIB . "Avos/Admin.php");
include(LIB . "Avos/Users.php");
include(LIB . "Ext/SimpleXLSX.php");
include(LIB . "Ext/Minifier.php");

\Avos\Utils\profFlag('start');

//
// check use of ?debug isnt disabled
//

if (isset($_GET['debug']) && getConfig('site', 'allowDebugFlag', 1) == 0) {
    unset($_GET['debug']);
}

//
// set the templates folder from whats defined by templates= or avos/templates
//

$tpl = getConfig('templates', 'theme', 'templates');
$ftpl = 'templates/' . rtrim($tpl, '/') . '/';

if (!file_exists(TOP . $ftpl)) {
    $ftpl = rtrim($tpl, '/') . '/';
}

define('SITETEMPLATES', TOP . $ftpl);

if (!defined('TEMPLATES')) {
    define('TEMPLATES', SITETEMPLATES);
}

$flavor = getConfig('templates', 'flavor', '');

if (!empty($flavor)) {
    define('TEMPLATES_FLAVOR', TEMPLATES . $flavor . '/');
}
else {
    define('TEMPLATES_FLAVOR', '');
}

//
// prefix php include path with flavor for include()'s
//

set_include_path(TEMPLATES . PATH_SEPARATOR . get_include_path());

if (!empty(TEMPLATES_FLAVOR)) {
    set_include_path(TEMPLATES_FLAVOR . PATH_SEPARATOR . get_include_path());
}

//
// prefix all other paths with avos/templates.site/
//

set_include_path(TOP . 'templates.site' . PATH_SEPARATOR . get_include_path());

//
// load templates/functions.php if exists
//

if (file_exists(SITETEMPLATES . 'functions.php')) {
    require(SITETEMPLATES . 'functions.php');
}

//
// theme settings
//

$includes = [];

if (file_exists(SITETEMPLATES . 'config')) {
    foreach (\Avos\Utils\list_files(SITETEMPLATES . 'config') as $file) {
        $includes[] = SITETEMPLATES . 'config/' . $file;
    }
}

if (file_exists(SITETEMPLATES . 'config.ini')) {
    $includes[] = SITETEMPLATES . 'config.ini';
}





foreach ($includes as $include) {
    foreach (parse_ini_file($include) as $k => $v) {
        if (isset($_GET['debug']) && isset($_AVOS['config']['templates'][$k]) && $v != $_AVOS['config']['templates'][$k]) {
            echo "warning: flavor setting [$k = $v] overridden by config.ini value of [" . $_AVOS['config']['templates'][$k] . "]<br>";
        }
        setTemplateValue($k, $v);
    }
}

//
// templates settings
//

// Original code for handling all includes except promote.ini
if (!empty($_AVOS['config']['templates'])) {
    foreach ($_AVOS['config']['templates'] as $k => $v) {
        if ($k !== 'includeM' && substr($k, 0, 7) == 'include' && file_exists(TOP . $v)) {
            foreach (parse_ini_file(TOP . $v) as $key => $value) {
                if (empty($_AVOS['config']['templates'][$key])) {
                    setTemplateValue($key, $value);
                } elseif (isset($_GET['debug']) && $value != $_AVOS['config']['templates'][$key]) {
                    echo "config.ini changed [$key] from [$value] to [" . $_AVOS['config']['templates'][$key] . "]<br>";
                }
            }
        } elseif ($k !== 'includeM') {
            setTemplateValue($k, $v);
        }
    }
}







// New code block for handling promote.ini separately
$promoteIniPath = TOP . 'templates/promote.ini';
if (file_exists($promoteIniPath)) {
    $promoteIniData = parse_ini_file($promoteIniPath);

    // Check if promote.ini has promotion dates
    if (isset($promoteIniData['datePromotionStart']) && isset($promoteIniData['datePromotionEnd'])) {
        $startDate = strtotime($promoteIniData['datePromotionStart']);
        $endDate = strtotime($promoteIniData['datePromotionEnd']);
        $currentDate = time();

        // Only include promote.ini if the current date is within the promotion period
        if ($currentDate >= $startDate && $currentDate <= $endDate) {
            foreach ($promoteIniData as $key => $value) {
                if (empty($_AVOS['config']['templates'][$key])) {
                    setTemplateValue($key, $value);
                } elseif (isset($_GET['debug']) && $value != $_AVOS['config']['templates'][$key]) {
                    echo "promote.ini changed [$key] from [$value] to [" . $_AVOS['config']['templates'][$key] . "]<br>";
                }
            }
        } else {
            if (isset($_GET['debug'])) {
                echo "Promotion period has ended or not yet started, skipping promote.ini.<br>";
            }
        }
    } else {
        // If no dates are set in promote.ini, load it as usual
        foreach ($promoteIniData as $key => $value) {
            if (empty($_AVOS['config']['templates'][$key])) {
                setTemplateValue($key, $value);
            } elseif (isset($_GET['debug']) && $value != $_AVOS['config']['templates'][$key]) {
                echo "promote.ini changed [$key] from [$value] to [" . $_AVOS['config']['templates'][$key] . "]<br>";
            }
        }
    }
}












//
// template flavor settings
//

if (!empty(TEMPLATES_FLAVOR) && file_exists(TEMPLATES_FLAVOR . 'config.ini')) {
    foreach (parse_ini_file(TEMPLATES_FLAVOR . 'config.ini') as $k => $v) {
        if (!isset($_AVOS['config']['templates'][$k])) {
            setTemplateValue($k, $v);
        }
        elseif (isset($_GET['debug']) && $v != $_AVOS['config']['templates'][$k]) {
            echo "warning: flavor setting [$k = $v] overridden by config.ini value of [" . $_AVOS['config']['templates'][$k] . "]<br>";
        }
    }
}

//
// check for colors referring to other elements
//

$vars = getTemplateValues();

foreach ($vars as $k => $v) {
    if (ctype_alpha($v) && !empty($vars[$v])) {

        $i = 0;
        while (ctype_alpha($v) && !empty($vars[$v]) && $i++ < 10) {
            $v = $vars[$v];
        }

        setTemplateValue($k, $v);
    }
}

//
// add refresh template value
//

if (isset($_GET['refresh']) | (!empty($_AVOS['config']['site']['refresh']) && $_AVOS['config']['site']['refresh'] == 1)) {
    setTemplateValue('refresh', '?' . time());
}
else {
    setTemplateValue('refresh', '');
}

//
// optionally include a sub template for values within the webcams block to overide settings
//

if (!empty($_AVOS['config']['webcams']['include'])) {
    $webcams = parse_ini_file(TOP . $_AVOS['config']['webcams']['include']);

    foreach ($webcams as $k => $v) {
        if (is_array($v)) {
            foreach ($v as $k2 => $v2) {
                $_AVOS['config']['webcams'][$k][$k2] = $v2;
            }
        }
        else {
            $_AVOS['config']['webcams'][$k] = $v;
        }
    }
}

