<?php
namespace Avos\Webcams;

function getRanks($m, $normalised=0, $months=0)
{
	#$t = \Avos\Redis\getModel($m['id'], "/rank/", true);
	return \Avos\Redis\getRanks($m['id'], $normalised, $months);
}

function getActivityFeed($m, $months=0)
{
	/*
	 * pre redis
	 (

	$feed = \Avos\Database\queryAssoc('
				SELECT epochTime, status, statusTime 
				FROM history 
				WHERE webcamsId=:id
				ORDER BY epochTime DESC
				LIMIT 30
			', $m);
	*/

	$feed = \Avos\Redis\getHistory($m['id'], 30, true, $months);

	foreach ($feed as $i => $f) {

		$feed[$i]['epochTime'] = $f['epochTime'] = $f['epochTime'] * 60 + EPOCHSTART;

		$feed[$i]['statusStr'] = \Avos\Utils\longStatus($f['status']);
		$feed[$i]['dateStr'] = date('d M y g:i a', $f['epochTime']);
		$feed[$i]['timeStr'] = \Avos\Utils\seconds2string($f['statusTime'], false, true);

		if ($f['statusTime'] > 0) {
			$feed[$i]['activityStr'] = $feed[$i]['dateStr'] . ' ' . $feed[$i]['statusStr'] . ' for ' . $feed[$i]['timeStr'];
		}
		else {
			$feed[$i]['activityStr'] = $feed[$i]['dateStr'] . ' ' . $feed[$i]['statusStr'] . ' started';
		}
	}

	return $feed;
}

//
// return daily hours worked for current and previous months
//

function getDailyHours($m, $months=0)
{
	$year = (int)date('y', time());

	if ($months > 0) {
		$month = 0 - $months;
	}
	else {
		$month = (int)date('n', time());
	}

	//
	// extract daily stats for this and last month
	//

	/*
	$curr = \Avos\Redis\getStats($m['id'], 'd', $year, $month, '*', true);

	$month--;
	if ($month < 1) {
		$year--;
		$month = 12;
	}

	$prev = \Avos\Redis\getStats($m['id'], 'd', $year, $month);
	$both = array_merge($curr, $prev);
	*/

	$both = \Avos\Redis\getStats($m['id'], 'd', '*', $month);

	//
	// now total up hours
	//

	$ret = array();

	foreach ($both as $d) {
		$ret[] = array(
			'year' => $d['year'],
			'month' => $d['month'],
			'day' => $d['day'],
			'dateStr' => \Avos\Utils\ordinal($d['day']) . ' ' . \Avos\Utils\monthName($d['month']),

			'awayTime' => $d['awayTime'],
			'awayTimeStr' => \Avos\Utils\seconds2string($d['awayTime'], false, true),

			'freechatTime' => $d['freechatTime'],
			'freechatTimeStr' => \Avos\Utils\seconds2string($d['freechatTime'], false, true),

			'groupTime' => $d['groupTime'],
			'groupTimeStr' => \Avos\Utils\seconds2string($d['groupTime'], false, true),

			'privateTime' => $d['privateTime'],
			'privateTimeStr' => \Avos\Utils\seconds2string($d['privateTime'], false, true),

			'time' => $d['awayTime'] + $d['freechatTime'] + $d['groupTime'] + $d['privateTime'],
			'timeStr' => \Avos\Utils\seconds2string($d['awayTime'] + $d['freechatTime'] + $d['groupTime'] + $d['privateTime'], false, true),
		);
	}

	return array_reverse($ret);
}

function getHeatMap($m)
{
	global $_AVOS;

	/*
	 * pre redis
	 *

	$history = \Avos\Database\queryAssoc('SELECT epochTime, statusTime FROM history WHERE webcamsId=:id', $m);
	*/

	$history = \Avos\Scaffold\getCache('history' . $m['id']);
	
	if ($history == false) {
		$history = \Avos\Redis\getHistory($m['id']);
	}

	// create empty slots of each day/hour
	$dnames = array('Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun');
	$dnamesh = array('Mon' => 0, 'Tue' => 1, 'Wed' => 2, 'Thu' => 3, 'Fri' => 4, 'Sat' => 5, 'Sun' => 6);

	$heatmap = array();
	for ($days=0; $days<7; $days++) {
		$heatmap[$dnames[$days]] = array();
		for ($hours=0; $hours<24; $hours++) {
			$heatmap[$dnames[$days]][] = 0;
		}
	}

	// find maximum value so we can normalise from 0 - 10

	/*
	$max = 0;

	foreach ($history as $h) {
		if ($h['statusTime'] > $max) {
			$max = $h['statusTime'];
		}
	}
	*/

	// update each day/hour with normalised value

	$max = 1;

	foreach ($history as $h) {

		// check for junk data, 10 hrs
		if ($h['statusTime'] > 36000) {
			$h['statusTime'] = 36000;
		}

		// mon=1 so subtract 1
		#$day = date("N", $h['epochTime']) - 1;
		$day = date("D", $h['epochTime']);
		$hour = date("G", $h['epochTime']);
		$hours = $hour + floor($h['statusTime'] / 3600) + 1;

		#echo "<pre>day=$day hour=$hour statusTime=$h[statusTime] max hour=$hours\n";

		for ($i = $hour, $ii = $hour; $i < $hours; $i++, $ii++) {

			// check to see if we go over midnight
			if ($ii >= 24) {
				$ii = 0;
				$dayIdx = $dnamesh[ $day ];
				$dayIdx++;

				// check to see if we go over sunday
				if ($dayIdx == 7) {
					$dayIdx = 0;
				}

				$day = $dnames[ $dayIdx ];
			}

			#echo "found hour $day/$ii\n";
			// add 100 to ensure its bigger than what we want to normalise to
			$heatmap[$day][$ii] += 100;
		
			// see if this is the max value
			if ($heatmap[$day][$ii] > $max) {
				$max = $heatmap[$day][$ii];
			}
		}

	}
	#print_r($heatmap); exit;

	// normalise the values from 1-10

	foreach ($heatmap as $day => $hours) {
		foreach ($hours as $hour => $time) {
			$heatmap[$day][$hour] = floor($time * 10 / $max);
			#echo $heatmap[$day][$hour] . "<br>";
		}
	}

	#echo "<pre>\n"; print_r($heatmap); exit;

	return $heatmap;
}


